Documentation
¶
Index ¶
- type ApplicationLister
- type ApplicationListerExpansion
- type ApplicationNamespaceLister
- type ApplicationNamespaceListerExpansion
- type ApplicationURLDispatchRulesLister
- type ApplicationURLDispatchRulesListerExpansion
- type ApplicationURLDispatchRulesNamespaceLister
- type ApplicationURLDispatchRulesNamespaceListerExpansion
- type DomainMappingLister
- type DomainMappingListerExpansion
- type DomainMappingNamespaceLister
- type DomainMappingNamespaceListerExpansion
- type FirewallRuleLister
- type FirewallRuleListerExpansion
- type FirewallRuleNamespaceLister
- type FirewallRuleNamespaceListerExpansion
- type FlexibleAppVersionLister
- type FlexibleAppVersionListerExpansion
- type FlexibleAppVersionNamespaceLister
- type FlexibleAppVersionNamespaceListerExpansion
- type ServiceNetworkSettingsLister
- type ServiceNetworkSettingsListerExpansion
- type ServiceNetworkSettingsNamespaceLister
- type ServiceNetworkSettingsNamespaceListerExpansion
- type ServiceSplitTrafficLister
- type ServiceSplitTrafficListerExpansion
- type ServiceSplitTrafficNamespaceLister
- type ServiceSplitTrafficNamespaceListerExpansion
- type StandardAppVersionLister
- type StandardAppVersionListerExpansion
- type StandardAppVersionNamespaceLister
- type StandardAppVersionNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApplicationLister ¶
type ApplicationLister interface {
// List lists all Applications in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Application, err error)
// Applications returns an object that can list and get Applications.
Applications(namespace string) ApplicationNamespaceLister
ApplicationListerExpansion
}
ApplicationLister helps list Applications. All objects returned here must be treated as read-only.
func NewApplicationLister ¶
func NewApplicationLister(indexer cache.Indexer) ApplicationLister
NewApplicationLister returns a new ApplicationLister.
type ApplicationListerExpansion ¶
type ApplicationListerExpansion interface{}
ApplicationListerExpansion allows custom methods to be added to ApplicationLister.
type ApplicationNamespaceLister ¶
type ApplicationNamespaceLister interface {
// List lists all Applications in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Application, err error)
// Get retrieves the Application from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Application, error)
ApplicationNamespaceListerExpansion
}
ApplicationNamespaceLister helps list and get Applications. All objects returned here must be treated as read-only.
type ApplicationNamespaceListerExpansion ¶
type ApplicationNamespaceListerExpansion interface{}
ApplicationNamespaceListerExpansion allows custom methods to be added to ApplicationNamespaceLister.
type ApplicationURLDispatchRulesLister ¶
type ApplicationURLDispatchRulesLister interface {
// List lists all ApplicationURLDispatchRuleses in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ApplicationURLDispatchRules, err error)
// ApplicationURLDispatchRuleses returns an object that can list and get ApplicationURLDispatchRuleses.
ApplicationURLDispatchRuleses(namespace string) ApplicationURLDispatchRulesNamespaceLister
ApplicationURLDispatchRulesListerExpansion
}
ApplicationURLDispatchRulesLister helps list ApplicationURLDispatchRuleses. All objects returned here must be treated as read-only.
func NewApplicationURLDispatchRulesLister ¶
func NewApplicationURLDispatchRulesLister(indexer cache.Indexer) ApplicationURLDispatchRulesLister
NewApplicationURLDispatchRulesLister returns a new ApplicationURLDispatchRulesLister.
type ApplicationURLDispatchRulesListerExpansion ¶
type ApplicationURLDispatchRulesListerExpansion interface{}
ApplicationURLDispatchRulesListerExpansion allows custom methods to be added to ApplicationURLDispatchRulesLister.
type ApplicationURLDispatchRulesNamespaceLister ¶
type ApplicationURLDispatchRulesNamespaceLister interface {
// List lists all ApplicationURLDispatchRuleses in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ApplicationURLDispatchRules, err error)
// Get retrieves the ApplicationURLDispatchRules from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ApplicationURLDispatchRules, error)
ApplicationURLDispatchRulesNamespaceListerExpansion
}
ApplicationURLDispatchRulesNamespaceLister helps list and get ApplicationURLDispatchRuleses. All objects returned here must be treated as read-only.
type ApplicationURLDispatchRulesNamespaceListerExpansion ¶
type ApplicationURLDispatchRulesNamespaceListerExpansion interface{}
ApplicationURLDispatchRulesNamespaceListerExpansion allows custom methods to be added to ApplicationURLDispatchRulesNamespaceLister.
type DomainMappingLister ¶
type DomainMappingLister interface {
// List lists all DomainMappings in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.DomainMapping, err error)
// DomainMappings returns an object that can list and get DomainMappings.
DomainMappings(namespace string) DomainMappingNamespaceLister
DomainMappingListerExpansion
}
DomainMappingLister helps list DomainMappings. All objects returned here must be treated as read-only.
func NewDomainMappingLister ¶
func NewDomainMappingLister(indexer cache.Indexer) DomainMappingLister
NewDomainMappingLister returns a new DomainMappingLister.
type DomainMappingListerExpansion ¶
type DomainMappingListerExpansion interface{}
DomainMappingListerExpansion allows custom methods to be added to DomainMappingLister.
type DomainMappingNamespaceLister ¶
type DomainMappingNamespaceLister interface {
// List lists all DomainMappings in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.DomainMapping, err error)
// Get retrieves the DomainMapping from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.DomainMapping, error)
DomainMappingNamespaceListerExpansion
}
DomainMappingNamespaceLister helps list and get DomainMappings. All objects returned here must be treated as read-only.
type DomainMappingNamespaceListerExpansion ¶
type DomainMappingNamespaceListerExpansion interface{}
DomainMappingNamespaceListerExpansion allows custom methods to be added to DomainMappingNamespaceLister.
type FirewallRuleLister ¶
type FirewallRuleLister interface {
// List lists all FirewallRules in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.FirewallRule, err error)
// FirewallRules returns an object that can list and get FirewallRules.
FirewallRules(namespace string) FirewallRuleNamespaceLister
FirewallRuleListerExpansion
}
FirewallRuleLister helps list FirewallRules. All objects returned here must be treated as read-only.
func NewFirewallRuleLister ¶
func NewFirewallRuleLister(indexer cache.Indexer) FirewallRuleLister
NewFirewallRuleLister returns a new FirewallRuleLister.
type FirewallRuleListerExpansion ¶
type FirewallRuleListerExpansion interface{}
FirewallRuleListerExpansion allows custom methods to be added to FirewallRuleLister.
type FirewallRuleNamespaceLister ¶
type FirewallRuleNamespaceLister interface {
// List lists all FirewallRules in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.FirewallRule, err error)
// Get retrieves the FirewallRule from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.FirewallRule, error)
FirewallRuleNamespaceListerExpansion
}
FirewallRuleNamespaceLister helps list and get FirewallRules. All objects returned here must be treated as read-only.
type FirewallRuleNamespaceListerExpansion ¶
type FirewallRuleNamespaceListerExpansion interface{}
FirewallRuleNamespaceListerExpansion allows custom methods to be added to FirewallRuleNamespaceLister.
type FlexibleAppVersionLister ¶
type FlexibleAppVersionLister interface {
// List lists all FlexibleAppVersions in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.FlexibleAppVersion, err error)
// FlexibleAppVersions returns an object that can list and get FlexibleAppVersions.
FlexibleAppVersions(namespace string) FlexibleAppVersionNamespaceLister
FlexibleAppVersionListerExpansion
}
FlexibleAppVersionLister helps list FlexibleAppVersions. All objects returned here must be treated as read-only.
func NewFlexibleAppVersionLister ¶
func NewFlexibleAppVersionLister(indexer cache.Indexer) FlexibleAppVersionLister
NewFlexibleAppVersionLister returns a new FlexibleAppVersionLister.
type FlexibleAppVersionListerExpansion ¶
type FlexibleAppVersionListerExpansion interface{}
FlexibleAppVersionListerExpansion allows custom methods to be added to FlexibleAppVersionLister.
type FlexibleAppVersionNamespaceLister ¶
type FlexibleAppVersionNamespaceLister interface {
// List lists all FlexibleAppVersions in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.FlexibleAppVersion, err error)
// Get retrieves the FlexibleAppVersion from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.FlexibleAppVersion, error)
FlexibleAppVersionNamespaceListerExpansion
}
FlexibleAppVersionNamespaceLister helps list and get FlexibleAppVersions. All objects returned here must be treated as read-only.
type FlexibleAppVersionNamespaceListerExpansion ¶
type FlexibleAppVersionNamespaceListerExpansion interface{}
FlexibleAppVersionNamespaceListerExpansion allows custom methods to be added to FlexibleAppVersionNamespaceLister.
type ServiceNetworkSettingsLister ¶
type ServiceNetworkSettingsLister interface {
// List lists all ServiceNetworkSettingses in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ServiceNetworkSettings, err error)
// ServiceNetworkSettingses returns an object that can list and get ServiceNetworkSettingses.
ServiceNetworkSettingses(namespace string) ServiceNetworkSettingsNamespaceLister
ServiceNetworkSettingsListerExpansion
}
ServiceNetworkSettingsLister helps list ServiceNetworkSettingses. All objects returned here must be treated as read-only.
func NewServiceNetworkSettingsLister ¶
func NewServiceNetworkSettingsLister(indexer cache.Indexer) ServiceNetworkSettingsLister
NewServiceNetworkSettingsLister returns a new ServiceNetworkSettingsLister.
type ServiceNetworkSettingsListerExpansion ¶
type ServiceNetworkSettingsListerExpansion interface{}
ServiceNetworkSettingsListerExpansion allows custom methods to be added to ServiceNetworkSettingsLister.
type ServiceNetworkSettingsNamespaceLister ¶
type ServiceNetworkSettingsNamespaceLister interface {
// List lists all ServiceNetworkSettingses in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ServiceNetworkSettings, err error)
// Get retrieves the ServiceNetworkSettings from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ServiceNetworkSettings, error)
ServiceNetworkSettingsNamespaceListerExpansion
}
ServiceNetworkSettingsNamespaceLister helps list and get ServiceNetworkSettingses. All objects returned here must be treated as read-only.
type ServiceNetworkSettingsNamespaceListerExpansion ¶
type ServiceNetworkSettingsNamespaceListerExpansion interface{}
ServiceNetworkSettingsNamespaceListerExpansion allows custom methods to be added to ServiceNetworkSettingsNamespaceLister.
type ServiceSplitTrafficLister ¶
type ServiceSplitTrafficLister interface {
// List lists all ServiceSplitTraffics in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ServiceSplitTraffic, err error)
// ServiceSplitTraffics returns an object that can list and get ServiceSplitTraffics.
ServiceSplitTraffics(namespace string) ServiceSplitTrafficNamespaceLister
ServiceSplitTrafficListerExpansion
}
ServiceSplitTrafficLister helps list ServiceSplitTraffics. All objects returned here must be treated as read-only.
func NewServiceSplitTrafficLister ¶
func NewServiceSplitTrafficLister(indexer cache.Indexer) ServiceSplitTrafficLister
NewServiceSplitTrafficLister returns a new ServiceSplitTrafficLister.
type ServiceSplitTrafficListerExpansion ¶
type ServiceSplitTrafficListerExpansion interface{}
ServiceSplitTrafficListerExpansion allows custom methods to be added to ServiceSplitTrafficLister.
type ServiceSplitTrafficNamespaceLister ¶
type ServiceSplitTrafficNamespaceLister interface {
// List lists all ServiceSplitTraffics in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ServiceSplitTraffic, err error)
// Get retrieves the ServiceSplitTraffic from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ServiceSplitTraffic, error)
ServiceSplitTrafficNamespaceListerExpansion
}
ServiceSplitTrafficNamespaceLister helps list and get ServiceSplitTraffics. All objects returned here must be treated as read-only.
type ServiceSplitTrafficNamespaceListerExpansion ¶
type ServiceSplitTrafficNamespaceListerExpansion interface{}
ServiceSplitTrafficNamespaceListerExpansion allows custom methods to be added to ServiceSplitTrafficNamespaceLister.
type StandardAppVersionLister ¶
type StandardAppVersionLister interface {
// List lists all StandardAppVersions in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.StandardAppVersion, err error)
// StandardAppVersions returns an object that can list and get StandardAppVersions.
StandardAppVersions(namespace string) StandardAppVersionNamespaceLister
StandardAppVersionListerExpansion
}
StandardAppVersionLister helps list StandardAppVersions. All objects returned here must be treated as read-only.
func NewStandardAppVersionLister ¶
func NewStandardAppVersionLister(indexer cache.Indexer) StandardAppVersionLister
NewStandardAppVersionLister returns a new StandardAppVersionLister.
type StandardAppVersionListerExpansion ¶
type StandardAppVersionListerExpansion interface{}
StandardAppVersionListerExpansion allows custom methods to be added to StandardAppVersionLister.
type StandardAppVersionNamespaceLister ¶
type StandardAppVersionNamespaceLister interface {
// List lists all StandardAppVersions in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.StandardAppVersion, err error)
// Get retrieves the StandardAppVersion from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.StandardAppVersion, error)
StandardAppVersionNamespaceListerExpansion
}
StandardAppVersionNamespaceLister helps list and get StandardAppVersions. All objects returned here must be treated as read-only.
type StandardAppVersionNamespaceListerExpansion ¶
type StandardAppVersionNamespaceListerExpansion interface{}
StandardAppVersionNamespaceListerExpansion allows custom methods to be added to StandardAppVersionNamespaceLister.